bioodo package
==============

Submodules
----------

bioodo\.bamtools module
-----------------------

.. automodule:: bioodo.bamtools
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.bcftools module
-----------------------

.. automodule:: bioodo.bcftools
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.bwa module
------------------

.. automodule:: bioodo.bwa
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.config module
---------------------

.. automodule:: bioodo.config
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.cutadapt module
-----------------------

.. automodule:: bioodo.cutadapt
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.fastqc module
---------------------

.. automodule:: bioodo.fastqc
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.mapdamage module
------------------------

.. automodule:: bioodo.mapdamage
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.pandas module
---------------------

.. automodule:: bioodo.pandas
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.picard module
---------------------

.. automodule:: bioodo.picard
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.qualimap module
-----------------------

.. automodule:: bioodo.qualimap
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.rpkmforgenes module
---------------------------

.. automodule:: bioodo.rpkmforgenes
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.rsem module
-------------------

.. automodule:: bioodo.rsem
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.rseqc module
--------------------

.. automodule:: bioodo.rseqc
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.samtools module
-----------------------

.. automodule:: bioodo.samtools
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.settings module
-----------------------

.. automodule:: bioodo.settings
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.sga module
------------------

.. automodule:: bioodo.sga
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.star module
-------------------

.. automodule:: bioodo.star
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.utils module
--------------------

.. automodule:: bioodo.utils
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.vsearch module
----------------------

.. automodule:: bioodo.vsearch
    :members:
    :undoc-members:
    :show-inheritance:

bioodo\.xls module
------------------

.. automodule:: bioodo.xls
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: bioodo
    :members:
    :undoc-members:
    :show-inheritance:
